DROP TABLE Telefone_f;
DROP TABLE Inscricao;
DROP TABLE Participa;
DROP TABLE Turma;
DROP TABLE Curso;
DROP TABLE Professor;
DROP TABLE Funcionario;
DROP TABLE Telefone_r;
DROP TABLE Aluno;
DROP TABLE Responsavel;
DROP TABLE Projeto;
DROP TABLE Oficina;

CREATE TABLE Funcionario (
	cpf_f NUMBER,
	nome VARCHAR2(50) NOT NULL,
	rg NUMBER UNIQUE NOT NULL,
	email VARCHAR2(30) NOT NULL,
	funcao VARCHAR2(20) NOT NULL,
	cep VARCHAR2(9) NOT NULL, /* 00000-000 */
	numero NUMBER NOT NULL,
	complemento VARCHAR2(10),
	cpf_chefe NUMBER,
	PRIMARY KEY (cpf_f),
	FOREIGN KEY (cpf_chefe) REFERENCES Funcionario (cpf_f),
	CONSTRAINT Funcionario_cep_ck CHECK (cep LIKE '_____-___')
);

	
CREATE TABLE Telefone_f (
	cpf_f NUMBER,
	telefone NUMBER, /* novamente, mesma coisa do CPF e cep, com a vantagem de que daria pra colocar at o cdigo de rea */
	PRIMARY KEY (cpf_f, telefone),
	FOREIGN KEY (cpf_f) REFERENCES Funcionario (cpf_f)
);

CREATE TABLE Professor (
	cpf_p NUMBER,
	PRIMARY KEY (cpf_p),
	FOREIGN KEY (cpf_p) REFERENCES Funcionario (cpf_f)
);

CREATE TABLE Curso (
	cod_c NUMBER, /* sujeito  alterao caso seja texto */
	idioma VARCHAR2(8) UNIQUE NOT NULL,
	cpf_coord NUMBER,
	PRIMARY KEY (cod_c),
	FOREIGN KEY (cpf_coord) REFERENCES Professor (cpf_p)
);
	
CREATE TABLE Turma (
	cod_c NUMBER, /* sujeito  alterao caso seja texto */
	n_fila NUMBER,
	cpf_p NUMBER,
	dia VARCHAR2(7) NOT NULL,
	turno CHAR(1) NOT NULL, /* M, T, N */
	sala NUMBER NOT NULL, /* sujeito  alterao caso seja texto */
	nivel CHAR(1) NOT NULL, /* bsico = B, intermedirio = I, avanado = A*/
	idade_max NUMBER NOT NULL,
	idade_min NUMBER NOT NULL,
	CONSTRAINT Turma_pk PRIMARY KEY (cod_c, n_fila),
	FOREIGN KEY (cod_c) REFERENCES Curso (cod_c),
	FOREIGN KEY (cpf_p) REFERENCES Professor (cpf_p)
);

CREATE TABLE Responsavel (
	cpf_r NUMBER,
	nome VARCHAR2(50) NOT NULL,
	rg NUMBER UNIQUE NOT NULL,
	email VARCHAR2(30) NOT NULL,
	cep VARCHAR2(9) NOT NULL, /* 00000-000 */
	numero NUMBER NOT NULL,
	complemento VARCHAR2(10),
	PRIMARY KEY (cpf_r),
	CONSTRAINT Responsavel_cep_ck CHECK (cep LIKE '_____-___')
);

CREATE TABLE Telefone_r (
	cpf_r NUMBER,
	telefone NUMBER,
	PRIMARY KEY (telefone, cpf_r),
	FOREIGN KEY (cpf_r) REFERENCES Responsavel (cpf_r)
);

CREATE TABLE Aluno (
	matricula NUMBER,
	cpf_r NUMBER,
	nome VARCHAR2(50) NOT NULL,
	rg NUMBER UNIQUE NOT NULL,
	data_nasc DATE NOT NULL,
	PRIMARY KEY (matricula),
	FOREIGN KEY (cpf_r) REFERENCES Responsavel (cpf_r)
);

CREATE TABLE Projeto (
	cod_p NUMBER,
	tema VARCHAR2(15) NOT NULL,
	descricao VARCHAR2(100) NOT NULL,
	nota DECIMAL(3,1),
	PRIMARY KEY (cod_p)
);

CREATE TABLE Oficina (
	cod_o NUMBER,
	nome VARCHAR2(20) NOT NULL,
	sala NUMBER NOT NULL,
	dia VARCHAR2(7) NOT NULL,
	turno CHAR(1) NOT NULL,
	PRIMARY KEY (cod_o)
);

CREATE TABLE Participa (
	cod_o NUMBER,
	matricula NUMBER,
	cpf_f NUMBER,
	PRIMARY KEY (cod_o, matricula, cpf_f),
	FOREIGN KEY (cod_o) REFERENCES Oficina (cod_o),
	FOREIGN KEY (matricula) REFERENCES Aluno (matricula),
	FOREIGN KEY (cpf_f) REFERENCES Professor (cpf_p)
);

CREATE TABLE Inscricao (
	semestre VARCHAR2(6), /* para colocar no formato "2011.2", por exemplo */
	matricula NUMBER,
	cod_c NUMBER,
	n_fila NUMBER,
	conversacao DECIMAL(3,1),
	leitura DECIMAL(3,1),
	escrita DECIMAL(3,1),
	cod_p NUMBER,
	PRIMARY KEY (semestre, matricula, cod_c, n_fila),
	FOREIGN KEY (matricula) REFERENCES Aluno (matricula),
	FOREIGN KEY (cod_c, n_fila) REFERENCES Turma (cod_c, n_fila),
	FOREIGN KEY (cod_p) REFERENCES Projeto (cod_p),
	CONSTRAINT Inscricao_semestre_ck CHECK (semestre LIKE '____._')
);